diff --git a/src/backend/executor/spi.c b/src/backend/executor/spi.c
index 7ccabdb..3c2f2bb 100644
--- a/src/backend/executor/spi.c
+++ b/src/backend/executor/spi.c
@@ -2226,8 +2226,13 @@ _SPI_execute_plan(SPIPlanPtr plan, ParamListInfo paramLI,
 							pg_strtouint64(completionTag + 7, NULL, 10);
 					else
 					{
-						/* Must be an IF NOT EXISTS that did nothing */
-						Assert(ctastmt->if_not_exists);
+						/*
+						 * Must be an IF NOT EXISTS that did nothing, or a CREATE
+						 * MATERIALIZED VIEW WITH NO DATA.
+						 */
+						Assert(ctastmt->if_not_exists ||
+							   (ctastmt->relkind == OBJECT_MATVIEW &&
+								ctastmt->into->skipData));
 						_SPI_current->processed = 0;
 					}
 
diff --git a/src/test/regress/expected/matview.out b/src/test/regress/expected/matview.out
index 102bf1f..65635b4 100644
--- a/src/test/regress/expected/matview.out
+++ b/src/test/regress/expected/matview.out
@@ -557,3 +557,19 @@ REFRESH MATERIALIZED VIEW mvtest_mv_foo;
 REFRESH MATERIALIZED VIEW CONCURRENTLY mvtest_mv_foo;
 DROP OWNED BY regress_user_mvtest CASCADE;
 DROP ROLE regress_user_mvtest;
+-- make sure that create WITH [ NO ] DATA works in functions
+CREATE OR REPLACE FUNCTION mvtest_func()
+  RETURNS void AS $$
+BEGIN
+  CREATE MATERIALIZED VIEW mvtest AS SELECT 1;
+  CREATE MATERIALIZED VIEW mvtest2 AS SELECT 1 WITH NO DATA;
+ END;
+$$ LANGUAGE plpgsql;
+SELECT mvtest_func();
+ mvtest_func 
+-------------
+ 
+(1 row)
+
+DROP MATERIALIZED VIEW mvtest;
+DROP MATERIALIZED VIEW mvtest2;
diff --git a/src/test/regress/sql/matview.sql b/src/test/regress/sql/matview.sql
index a108b69..6fc2d33 100644
--- a/src/test/regress/sql/matview.sql
+++ b/src/test/regress/sql/matview.sql
@@ -226,3 +226,15 @@ REFRESH MATERIALIZED VIEW mvtest_mv_foo;
 REFRESH MATERIALIZED VIEW CONCURRENTLY mvtest_mv_foo;
 DROP OWNED BY regress_user_mvtest CASCADE;
 DROP ROLE regress_user_mvtest;
+
+-- make sure that create WITH [ NO ] DATA works in functions
+CREATE OR REPLACE FUNCTION mvtest_func()
+  RETURNS void AS $$
+BEGIN
+  CREATE MATERIALIZED VIEW mvtest AS SELECT 1;
+  CREATE MATERIALIZED VIEW mvtest2 AS SELECT 1 WITH NO DATA;
+ END;
+$$ LANGUAGE plpgsql;
+SELECT mvtest_func();
+DROP MATERIALIZED VIEW mvtest;
+DROP MATERIALIZED VIEW mvtest2;
